# Copyright (c) 2017-2018 M. Grady Saunders
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 
#   1. Redistributions of source code must retain the above
#      copyright notice, this list of conditions and the following
#      disclaimer.
# 
#   2. Redistributions in binary form must reproduce the above
#      copyright notice, this list of conditions and the following
#      disclaimer in the documentation and/or other materials
#      provided with the distribution.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
# OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

module Schizm

  # https://material.io/guidelines/style/color.html
  COLORS = {
    'red' => {
        '50' => ['#FFEBEE', '#222222'],
       '100' => ['#FFCDD2', '#222222'],
       '200' => ['#EF9A9A', '#222222'],
       '300' => ['#E57373', '#222222'],
       '400' => ['#EF5350', '#EEEEEE'],
       '500' => ['#F44336', '#EEEEEE'],
       '600' => ['#E53935', '#EEEEEE'],
       '700' => ['#D32F2F', '#EEEEEE'],
       '800' => ['#C62828', '#EEEEEE'],
       '900' => ['#B71C1C', '#EEEEEE'],
      'A100' => ['#FF8A80', '#222222'],
      'A200' => ['#FF5252', '#EEEEEE'],
      'A400' => ['#FF1744', '#EEEEEE'],
      'A700' => ['#D50000', '#EEEEEE']
    },
    'pink' => {
        '50' => ['#FCE4EC', '#222222'],
       '100' => ['#F8BBD0', '#222222'],
       '200' => ['#F48FB1', '#222222'],
       '300' => ['#F06292', '#222222'],
       '400' => ['#EC407A', '#EEEEEE'],
       '500' => ['#E91E63', '#EEEEEE'],
       '600' => ['#D81B60', '#EEEEEE'],
       '700' => ['#C2185B', '#EEEEEE'],
       '800' => ['#AD1457', '#EEEEEE'],
       '900' => ['#880E4F', '#EEEEEE'],
      'A100' => ['#FF80AB', '#222222'],
      'A200' => ['#FF4081', '#EEEEEE'],
      'A400' => ['#F50057', '#EEEEEE'],
      'A700' => ['#C51162', '#EEEEEE']
    },
    'purple' => {
        '50' => ['#F3E5F5', '#222222'],
       '100' => ['#E1BEE7', '#222222'],
       '200' => ['#CE93D8', '#222222'],
       '300' => ['#BA68C8', '#EEEEEE'],
       '400' => ['#AB47BC', '#EEEEEE'],
       '500' => ['#9C27B0', '#EEEEEE'],
       '600' => ['#8E24AA', '#EEEEEE'],
       '700' => ['#7B1FA2', '#EEEEEE'],
       '800' => ['#6A1B8A', '#EEEEEE'],
       '900' => ['#4A148C', '#EEEEEE'],
      'A100' => ['#EA80FC', '#222222'],
      'A200' => ['#E040FB', '#EEEEEE'],
      'A400' => ['#D500F9', '#EEEEEE'],
      'A700' => ['#AA00FF', '#EEEEEE']
    },
    'deep-purple' => {
        '50' => ['#EDE7F6', '#222222'],
       '100' => ['#D1C4E9', '#222222'],
       '200' => ['#B39DDB', '#222222'],
       '300' => ['#9575CD', '#EEEEEE'],
       '400' => ['#7E57C2', '#EEEEEE'],
       '500' => ['#673AB7', '#EEEEEE'],
       '600' => ['#5E35B1', '#EEEEEE'],
       '700' => ['#512DA8', '#EEEEEE'],
       '800' => ['#4527A0', '#EEEEEE'],
       '900' => ['#311B92', '#EEEEEE'],
      'A100' => ['#B388FF', '#222222'],
      'A200' => ['#7C4DFF', '#EEEEEE'],
      'A400' => ['#651FFF', '#EEEEEE'],
      'A700' => ['#6200EA', '#EEEEEE']
    },
    'indigo' => {
        '50' => ['#E8EAF6', '#222222'],
       '100' => ['#C5CAE9', '#222222'],
       '200' => ['#9FA8DA', '#222222'],
       '300' => ['#7986CB', '#EEEEEE'],
       '400' => ['#5C6BC0', '#EEEEEE'],
       '500' => ['#3F51B5', '#EEEEEE'],
       '600' => ['#3949AB', '#EEEEEE'],
       '700' => ['#303F9F', '#EEEEEE'],
       '800' => ['#283593', '#EEEEEE'],
       '900' => ['#1A237E', '#EEEEEE'],
      'A100' => ['#8C9EFF', '#222222'],
      'A200' => ['#536DFE', '#EEEEEE'],
      'A400' => ['#3D5AFE', '#EEEEEE'],
      'A700' => ['#304FFE', '#EEEEEE']
    },
    'blue' => {
        '50' => ['#E3F2FD', '#222222'],
       '100' => ['#BBDEFB', '#222222'],
       '200' => ['#90CAF9', '#222222'],
       '300' => ['#64B5F6', '#222222'],
       '400' => ['#42A5F5', '#222222'],
       '500' => ['#2196F3', '#222222'],
       '600' => ['#1E88E5', '#EEEEEE'],
       '700' => ['#1976D2', '#EEEEEE'],
       '800' => ['#1565C0', '#EEEEEE'],
       '900' => ['#0D47A1', '#EEEEEE'],
      'A100' => ['#82B1FF', '#222222'],
      'A200' => ['#448AFF', '#EEEEEE'],
      'A400' => ['#2979FF', '#EEEEEE'],
      'A700' => ['#2962FF', '#EEEEEE']
    },
    'light-blue' => {
        '50' => ['#E1F5FE', '#222222'],
       '100' => ['#B3E5FC', '#222222'],
       '200' => ['#81D4FA', '#222222'],
       '300' => ['#4FC3F7', '#222222'],
       '400' => ['#29B6F6', '#222222'],
       '500' => ['#03A9F4', '#222222'],
       '600' => ['#039BE5', '#222222'],
       '700' => ['#0288D1', '#EEEEEE'],
       '800' => ['#0277BD', '#EEEEEE'],
       '900' => ['#01579B', '#EEEEEE'],
      'A100' => ['#80D8FF', '#222222'],
      'A200' => ['#40C4FF', '#222222'],
      'A400' => ['#00B0FF', '#222222'],
      'A700' => ['#0091EA', '#EEEEEE']
    },
    'cyan' => {
        '50' => ['#E0F7FA', '#222222'],
       '100' => ['#B2EBF2', '#222222'],
       '200' => ['#80DEEA', '#222222'],
       '300' => ['#4DD0E1', '#222222'],
       '400' => ['#26C6DA', '#222222'],
       '500' => ['#00BCD4', '#222222'],
       '600' => ['#00ACC1', '#222222'],
       '700' => ['#0097A7', '#EEEEEE'],
       '800' => ['#00838F', '#EEEEEE'],
       '900' => ['#006064', '#EEEEEE'],
      'A100' => ['#84FFFF', '#222222'],
      'A200' => ['#18FFFF', '#222222'],
      'A400' => ['#00E5FF', '#222222'],
      'A700' => ['#00B8D4', '#222222']
    },
    'teal' => {
        '50' => ['#E0F2F1', '#222222'],
       '100' => ['#B2DFDB', '#222222'],
       '200' => ['#80CBC4', '#222222'],
       '300' => ['#4DB6AC', '#222222'],
       '400' => ['#26A69A', '#222222'],
       '500' => ['#009688', '#EEEEEE'],
       '600' => ['#00897B', '#EEEEEE'],
       '700' => ['#00796B', '#EEEEEE'],
       '800' => ['#00695C', '#EEEEEE'],
       '900' => ['#004D40', '#EEEEEE'],
      'A100' => ['#A7FFEB', '#222222'],
      'A200' => ['#64FFDA', '#222222'],
      'A400' => ['#1DE9B6', '#222222'],
      'A700' => ['#00BFA5', '#222222']
    },
    'green' => {
        '50' => ['#E8F5E9', '#222222'],
       '100' => ['#C8E6C9', '#222222'],
       '200' => ['#A5D6A7', '#222222'],
       '300' => ['#81C784', '#222222'],
       '400' => ['#66BB6A', '#222222'],
       '500' => ['#4CAF50', '#222222'],
       '600' => ['#43A047', '#EEEEEE'],
       '700' => ['#388E3C', '#EEEEEE'],
       '800' => ['#2E7D32', '#EEEEEE'],
       '900' => ['#1B5E20', '#EEEEEE'],
      'A100' => ['#B9F6CA', '#222222'],
      'A200' => ['#69F0AE', '#222222'],
      'A400' => ['#00E676', '#222222'],
      'A700' => ['#00C853', '#222222']
    },
    'light-green' => {
        '50' => ['#F1F8E9', '#222222'],
       '100' => ['#DCEDC8', '#222222'],
       '200' => ['#C5E1A5', '#222222'],
       '300' => ['#AED581', '#222222'],
       '400' => ['#9CCC65', '#222222'],
       '500' => ['#8BC34A', '#222222'],
       '600' => ['#7CB342', '#222222'],
       '700' => ['#689F38', '#222222'],
       '800' => ['#558B2F', '#EEEEEE'],
       '900' => ['#33691E', '#EEEEEE'],
      'A100' => ['#CCFF90', '#222222'],
      'A200' => ['#B2FF59', '#222222'],
      'A400' => ['#76FF03', '#222222'],
      'A700' => ['#64DD17', '#222222']
    },
    'lime' => {
        '50' => ['#F9FBE7', '#222222'],
       '100' => ['#F0F4C3', '#222222'],
       '200' => ['#E6EE9C', '#222222'],
       '300' => ['#DCE775', '#222222'],
       '400' => ['#D4E157', '#222222'],
       '500' => ['#CDDC39', '#222222'],
       '600' => ['#C0CA33', '#222222'],
       '700' => ['#AFB42B', '#222222'],
       '800' => ['#9E9D24', '#222222'],
       '900' => ['#827717', '#EEEEEE'],
      'A100' => ['#F4FF81', '#222222'],
      'A200' => ['#EEFF41', '#222222'],
      'A400' => ['#C6FF00', '#222222'],
      'A700' => ['#AEEA00', '#222222']
    },
    'yellow' => {
        '50' => ['#FFFDE7', '#222222'],
       '100' => ['#FFF9C4', '#222222'],
       '200' => ['#FFF59D', '#222222'],
       '300' => ['#FFF176', '#222222'],
       '400' => ['#FFEE58', '#222222'],
       '500' => ['#FFEB3B', '#222222'],
       '600' => ['#FDD835', '#222222'],
       '700' => ['#FBC02D', '#222222'],
       '800' => ['#F9A825', '#222222'],
       '900' => ['#F57F17', '#222222'],
      'A100' => ['#FFFF8D', '#222222'],
      'A200' => ['#FFFF00', '#222222'],
      'A400' => ['#FFEA00', '#222222'],
      'A700' => ['#FFD600', '#222222']
    },
    'amber' => {
        '50' => ['#FFF8E1', '#222222'],
       '100' => ['#FFECB3', '#222222'],
       '200' => ['#FFE082', '#222222'],
       '300' => ['#FFD54F', '#222222'],
       '400' => ['#FFCA28', '#222222'],
       '500' => ['#FFC107', '#222222'],
       '600' => ['#FFB300', '#222222'],
       '700' => ['#FFA000', '#222222'],
       '800' => ['#FF8F00', '#222222'],
       '900' => ['#FF6F00', '#222222'],
      'A100' => ['#FFE57F', '#222222'],
      'A200' => ['#FFD740', '#222222'],
      'A400' => ['#FFC400', '#222222'],
      'A700' => ['#FFAB00', '#222222']
    },
    'orange' => {
        '50' => ['#FFF3E0', '#222222'],
       '100' => ['#FFE0B2', '#222222'],
       '200' => ['#FFCC80', '#222222'],
       '300' => ['#FFB74D', '#222222'],
       '400' => ['#FFA726', '#222222'],
       '500' => ['#FF9800', '#222222'],
       '600' => ['#FB8C00', '#222222'],
       '700' => ['#F57C00', '#222222'],
       '800' => ['#EF6C00', '#222222'],
       '900' => ['#E65100', '#EEEEEE'],
      'A100' => ['#FFD180', '#222222'],
      'A200' => ['#FFAB40', '#222222'],
      'A400' => ['#FF9100', '#222222'],
      'A700' => ['#FF6D00', '#222222']
    },
    'deep-orange' => {
        '50' => ['#FBE9E7', '#222222'],
       '100' => ['#FFCCBC', '#222222'],
       '200' => ['#FFAB91', '#222222'],
       '300' => ['#FF8A65', '#222222'],
       '400' => ['#FF7043', '#222222'],
       '500' => ['#FF5722', '#222222'],
       '600' => ['#F4511E', '#EEEEEE'],
       '700' => ['#E64A19', '#EEEEEE'],
       '800' => ['#D84315', '#EEEEEE'],
       '900' => ['#BF360C', '#EEEEEE'],
      'A100' => ['#FF9E80', '#222222'],
      'A200' => ['#FF6E40', '#222222'],
      'A400' => ['#FF3D00', '#EEEEEE'],
      'A700' => ['#DD2C00', '#EEEEEE']
    }
  }

  # Create Sass-syntax color variables from +COLORS+.
  def self.sass_colors color, var
    colors = ""
    COLORS[color].each do |key, val|
      colors << "$#{var}-#{key}: #{val[0]};\n"
      colors << "$#{var}-#{key}-text: #{val[1]};\n"
    end
    return colors
  end

end # module Schizm
